@@ -8,16 +8,15 @@ def set_device_name(name):
 
 
 def get_device_name():
-    return os.environ['DEVICE'] if 'DEVICE' in os.environ else None
+    return os.environ['DEVICE']
 
 
 def get_device(i=0):
     name = get_device_name()
 
-    if 'gpu' in name:
-        name = f'cuda:{i}' if torch.cuda.device_count() >= i + 1 else 'cpu'
+    device = f'cuda:{i}' if (str_is_empty(name) or 'gpu' in name) and torch.cuda.device_count() >= i + 1 else 'cpu'
 
-    return torch.device(name)
+    return torch.device(device)
 
 
 def set_device_memory(device_name, process_memory_fraction=0.5):
@@ -27,3 +26,10 @@ def set_device_memory(device_name, process_memory_fraction=0.5):
             get_device()
         )
         torch.cuda.empty_cache()
+
+
+def str_is_empty(value):
+    return value is None or len(value) == 0
+
+
+set_device_name('')
